@@ -58,7 +58,8 @@ class GlobalException(Exception):
         url = None,
         logPayload = None,
         logHeaders = None,
-        context = None
+        context = None,
+        originalException = None
     ):
         self.timeStamp = DateTimeHelper.now()
         self.status = HttpStatus.map(DEFAULT_STATUS if ObjectHelper.isNone(status) else status).enumValue
@@ -71,6 +72,7 @@ class GlobalException(Exception):
         self.logPayload = logPayload if ObjectHelper.isNotNone(logPayload) else self.getRequestBody()
         self.logHeaders = logHeaders if ObjectHelper.isNotNone(logHeaders) else self.getRequestHeaders()
         self.context = HttpDomain.CONTROLLER_CONTEXT if ObjectHelper.isNone(context) else context
+        self.originalException = originalException
 
     def __str__(self):
         return f'''{GlobalException.__name__} thrown at {self.timeStamp}. Status: {self.status}, message: {self.message}, verb: {self.verb}, url: {self.url}{', logMessage: ' if self.logMessage else c.NOTHING}{self.logMessage}'''
@@ -102,10 +104,33 @@ def validateArgs(self, method, objectRequest, expecteObjectClass):
         log.failure(expecteObjectClass.__class__, f'Failed to validate args of {method.__name__} method', exception)
         raise GlobalException(logMessage = f'Failed to validate args of {method.__name__} method{DOT_SPACE_CAUSE}{str(exception)}')
 
+
 @Function
 def handleLogErrorException(exception, resourceInstance, resourceInstanceMethod, context, apiInstance = None) :
-    if not (isinstance(exception, GlobalException) or GlobalException.__name__ == exception.__class__.__name__) :
-        log.debug(handleLogErrorException, f'Failed to excecute {resourceInstanceMethod.__name__} method due to {exception.__class__.__name__} exception', exception=exception)
+    try :
+        exception = getGeneralGlobalException(exception, resourceInstance, resourceInstanceMethod, context, apiInstance = None)
+        httpErrorLog = ErrorLog.ErrorLog()
+        httpErrorLog.override(exception)
+        if ObjectHelper.isNone(apiInstance):
+            from python_framework import FlaskManager
+            apiInstance = FlaskManager.getApi()
+        else:
+            apiInstance = apiInstance
+            try:
+                apiInstance.repository.commit()
+            except Exception as preCommitException:
+                log.warning(handleLogErrorException, f'Failed to pre commit before persist {ErrorLog.ErrorLog.__name__}', exception=preCommitException)
+        apiInstance.repository.saveAndCommit(httpErrorLog)
+    except Exception as errorLogException :
+        log.warning(handleLogErrorException, f'Failed to persist {ErrorLog.ErrorLog.__name__}', exception=errorLogException)
+    return exception
+
+
+@Function
+def getGeneralGlobalException(exception, resourceInstance, resourceInstanceMethod, context, apiInstance = None):
+    originalException = exception
+    if not (isinstance(exception, GlobalException) or GlobalException.__name__ == exception.__class__.__name__):
+        log.debug(getGeneralGlobalException, f'Failed to excecute {resourceInstanceMethod.__name__} method due to {exception.__class__.__name__} exception', exception=exception)
         message = None
         status = None
         logMessage = None
@@ -124,7 +149,8 @@ def handleLogErrorException(exception, resourceInstance, resourceInstanceMethod,
             logMessage = logMessage,
             logResource = resourceInstance,
             logResourceMethod = resourceInstanceMethod,
-            status = status
+            status = status,
+            originalException = originalException
         )
     try :
         if not context == exception.context:
@@ -134,25 +160,34 @@ def handleLogErrorException(exception, resourceInstance, resourceInstanceMethod,
                 logResource = resourceInstance,
                 logResourceMethod = resourceInstanceMethod,
                 status = exception.status,
-                context = context
+                context = context,
+                originalException = originalException
             )
         else:
             if not exception.logResource or c.NOTHING == exception.logResource or not resourceInstance == exception.logResource :
                 exception.logResource = resourceInstance
             if not exception.logResourceMethod or c.NOTHING == exception.logResourceMethod or not resourceInstanceMethod == exception.logResourceMethod :
                 exception.logResourceMethod = resourceInstanceMethod
-        httpErrorLog = ErrorLog.ErrorLog()
-        httpErrorLog.override(exception)
-        if ObjectHelper.isNone(apiInstance):
-            from python_framework import FlaskManager
-            apiInstance = FlaskManager.getApi()
-        else:
-            apiInstance = apiInstance
-            try:
-                apiInstance.repository.commit()
-            except Exception as preCommitException:
-                log.warning(handleLogErrorException, f'Failed to pre commit before persist {ErrorLog.ErrorLog.__name__}', exception=preCommitException)
-        apiInstance.repository.saveAndCommit(httpErrorLog)
-    except Exception as errorLogException :
-        log.warning(handleLogErrorException, f'Failed to persist {ErrorLog.ErrorLog.__name__}', exception=errorLogException)
+    except Exception as globalExceptionHandlingException :
+        exception = GlobalException(originalException = originalException)
+        log.warning(getGeneralGlobalException, f'Failed to get GlobalException', exception=globalExceptionHandlingException)
     return exception
+
+
+@Function
+def getClientGlobalException(clientResponse, context, exception, logMessage, status=None, message=None):
+    raise GlobalException(
+        message = message,
+        logMessage = logMessage,
+        url = FlaskUtil.safellyGetRequestUrlFromResponse(clientResponse),
+        status = status if ObjectHelper.isNotNone(status) else FlaskUtil.safellyGetResponseStatus(clientResponse),
+        logHeaders = {
+            HttpDomain.REQUEST_HEADERS_KEY: FlaskUtil.safellyGetRequestHeadersFromResponse(clientResponse),
+            HttpDomain.RESPONSE_HEADERS_KEY: FlaskUtil.safellyGetResponseHeaders(clientResponse)
+        },
+        logPayload = {
+            HttpDomain.REQUEST_BODY_KEY: FlaskUtil.safellyGetRequestJsonFromResponse(clientResponse),
+            HttpDomain.RESPONSE_BODY_KEY: FlaskUtil.safellyGetResponseJson(clientResponse)
+        },
+        context = context
+    )
